@@ -18,10 +18,15 @@ from twitchdl.output import print_out
 def _parse_playlists(playlists_m3u8):
     playlists = m3u8.loads(playlists_m3u8)
 
-    for p in playlists.playlists:
-        name = p.media[0].name if p.media else ""
-        resolution = "x".join(str(r) for r in p.stream_info.resolution)
-        yield name, resolution, p.uri
+    for p in sorted(playlists.playlists, key=lambda p: p.stream_info.resolution is None):
+        if p.stream_info.resolution:
+            name = p.media[0].name
+            description = "x".join(str(r) for r in p.stream_info.resolution)
+        else:
+            name = p.media[0].group_id
+            description = None
+
+        yield name, description, p.uri
 
 
 def _get_playlist_by_name(playlists, quality):
@@ -41,7 +46,10 @@ def _get_playlist_by_name(playlists, quality):
 def _select_playlist_interactive(playlists):
     print_out("\nAvailable qualities:")
     for n, (name, resolution, uri) in enumerate(playlists):
-        print_out("{}) {} [{}]".format(n + 1, name, resolution))
+        if resolution:
+            print_out("{}) {} [{}]".format(n + 1, name, resolution))
+        else:
+            print_out("{}) {}".format(n + 1, name))
 
     no = utils.read_int("Choose quality", min=1, max=len(playlists) + 1, default=1)
     _, _, uri = playlists[no - 1]
@@ -58,7 +66,7 @@ def _join_vods(playlist_path, target, overwrite, video):
         "-metadata", "encoded_by=twitch-dl",
         "-stats",
         "-loglevel", "warning",
-        target,
+        "file:{}".format(target),
     ]
 
     if overwrite:
@@ -72,6 +80,7 @@ def _join_vods(playlist_path, target, overwrite, video):
 
 def _video_target_filename(video, args):
     date, time = video['publishedAt'].split("T")
+    game = video["game"]["name"] if video["game"] else "Unknown"
 
     subs = {
         "channel": video["creator"]["displayName"],
@@ -79,8 +88,8 @@ def _video_target_filename(video, args):
         "date": date,
         "datetime": video["publishedAt"],
         "format": args.format,
-        "game": video["game"]["name"],
-        "game_slug": utils.slugify(video["game"]["name"]),
+        "game": game,
+        "game_slug": utils.slugify(game),
         "id": video["id"],
         "time": time,
         "title": utils.titlify(video["title"]),
@@ -96,6 +105,7 @@ def _video_target_filename(video, args):
 
 def _clip_target_filename(clip, args):
     date, time = clip["createdAt"].split("T")
+    game = clip["game"]["name"] if clip["game"] else "Unknown"
 
     url = clip["videoQualities"][0]["sourceURL"]
     _, ext = path.splitext(url)
@@ -107,9 +117,10 @@ def _clip_target_filename(clip, args):
         "date": date,
         "datetime": clip["createdAt"],
         "format": ext,
-        "game": clip["game"]["name"],
-        "game_slug": utils.slugify(clip["game"]["name"]),
+        "game": game,
+        "game_slug": utils.slugify(game),
         "id": clip["id"],
+        "slug": clip["slug"],
         "time": time,
         "title": utils.titlify(clip["title"]),
         "title_slug": utils.slugify(clip["title"]),
@@ -210,6 +221,7 @@ def get_clip_authenticated_url(slug, quality):
 def _download_clip(slug, args):
     print_out("<dim>Looking up clip...</dim>")
     clip = twitch.get_clip(slug)
+    game = clip["game"]["name"] if clip["game"] else "Unknown"
 
     if not clip:
         raise ConsoleError("Clip '{}' not found".format(slug))
@@ -217,7 +229,7 @@ def _download_clip(slug, args):
     print_out("Found: <green>{}</green> by <yellow>{}</yellow>, playing <blue>{}</blue> ({})".format(
         clip["title"],
         clip["broadcaster"]["displayName"],
-        clip["game"]["name"],
+        game,
         utils.format_duration(clip["durationSeconds"])
     ))
 
