@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import logging
 import sys
 
 from argparse import ArgumentParser, ArgumentTypeError
@@ -33,15 +34,14 @@ def time(value):
     return hours * 3600 + minutes * 60 + seconds
 
 
-def limit(value):
-    """Validates the number of videos to fetch."""
+def pos_integer(value):
     try:
         value = int(value)
     except ValueError:
         raise ArgumentTypeError("must be an integer")
 
-    if not 1 <= int(value) <= 100:
-        raise ArgumentTypeError("must be between 1 and 100")
+    if value < 1:
+        raise ArgumentTypeError("must be positive")
 
     return value
 
@@ -61,10 +61,15 @@ COMMANDS = [
                 "type": str,
             }),
             (["-l", "--limit"], {
-                "help": "Number of videos to fetch (default 10, max 100)",
-                "type": limit,
+                "help": "Number of videos to fetch (default 10)",
+                "type": pos_integer,
                 "default": 10,
             }),
+            (["-a", "--all"], {
+                "help": "Fetch all videos, overrides --limit",
+                "action": "store_true",
+                "default": False,
+            }),
             (["-s", "--sort"], {
                 "help": "Sorting order of videos. (default: time)",
                 "type": str,
@@ -77,11 +82,17 @@ COMMANDS = [
                 "choices": ["archive", "highlight", "upload"],
                 "default": "archive",
             }),
-            (["-p", "--pager"], {
-                "help": "If there are more results than LIMIT, ask to show next page",
+            (["-j", "--json"], {
+                "help": "Show results as JSON. Ignores --pager.",
                 "action": "store_true",
                 "default": False,
             }),
+            (["-p", "--pager"], {
+                "help": "Number of videos to show per page. Disabled by default.",
+                "type": pos_integer,
+                "nargs": "?",
+                "const": 10,
+            }),
         ],
     ),
     Command(
@@ -94,9 +105,14 @@ COMMANDS = [
             }),
             (["-l", "--limit"], {
                 "help": "Number of videos to fetch (default 10, max 100)",
-                "type": limit,
+                "type": pos_integer,
                 "default": 10,
             }),
+            (["-a", "--all"], {
+                "help": "Fetch all videos, overrides --limit",
+                "action": "store_true",
+                "default": False,
+            }),
             (["-P", "--period"], {
                 "help": "Period from which to return clips. (default: 'all_time')",
                 "type": str,
@@ -109,9 +125,10 @@ COMMANDS = [
                 "default": False,
             }),
             (["-p", "--pager"], {
-                "help": "If there are more results than LIMIT, ask to show next page",
-                "action": "store_true",
-                "default": False,
+                "help": "Number of clips to show per page. Disabled by default.",
+                "type": pos_integer,
+                "nargs": "?",
+                "const": 10,
             }),
             (["-d", "--download"], {
                 "help": "Download all videos in given period (in source quality)",
@@ -231,6 +248,9 @@ def main():
     parser = get_parser()
     args = parser.parse_args()
 
+    if args.debug:
+        logging.basicConfig(level=logging.DEBUG)
+
     if args.version:
         print("twitch-dl v{}".format(__version__))
         return
